@@ -90,7 +90,7 @@ class Mpdclient(plugin.Plugin):
         try:
             self._mpdclient.connect(self._host, self._port)
             self._connected = True
-        except ConnectionError:
+        except mpd.base.ConnectionError:
             logger.error('could not connect to MPD')
 
     def on_connection_error(self) -> None:
@@ -112,7 +112,7 @@ class Mpdclient(plugin.Plugin):
         if self._connected:
             try:
                 self.check_mpd(save=True)
-            except ConnectionError:
+            except mpd.base.ConnectionError:
                 self.on_connection_error()
 
     def on_after_run(self) -> None:
@@ -123,7 +123,7 @@ class Mpdclient(plugin.Plugin):
                 self._mpdclient.stop()
                 self._mpdclient.close()
                 self._mpdclient.disconnect()
-            except ConnectionError:
+            except mpd.base.ConnectionError:
                 self.on_connection_error()
 
     def on_load_source(self, *values: str, **params: str) -> None:
@@ -155,10 +155,10 @@ class Mpdclient(plugin.Plugin):
 
         try:
             self._mpdclient.play()
-        except mpd.CommandError:
-            logger.error('could not apply status')
+        except mpd.CommandError as error:
+            logger.error(f'could not start playing ("{error}")')
             return
-        except ConnectionError:
+        except mpd.base.ConnectionError:
             self.on_connection_error()
             return
 
@@ -197,17 +197,18 @@ class Mpdclient(plugin.Plugin):
 
             if status.key[-4:] == '.m3u':
                 # the key indicates a playlist to be loaded
-                self._mpdclient.load(status.key[:-4])
+                # https://github.com/MusicPlayerDaemon/MPD/issues/200
+                self._mpdclient.load(status.key)
             else:
                 # the key represents a path to a folder the files in which are
                 # to be coerced into a playlist
                 self._mpdclient.add(status.key)
 
             self._mpdclient.seek(status.position, status.elapsed)
-        except mpd.CommandError:
-            logger.error('could not apply status')
+        except mpd.CommandError as error:
+            logger.error(f'could not apply status ("{error}")')
             return
-        except ConnectionError:
+        except mpd.base.ConnectionError:
             self.on_connection_error()
             return
         self._status = status
@@ -228,7 +229,7 @@ class Mpdclient(plugin.Plugin):
         try:
             mpd_status: dict[str, str] = self._mpdclient.status()
             if 'error' in mpd_status:
-                raise ConnectionError
+                raise mpd.base.ConnectionError
             status.state = mpd_status['state']
             if status.state == 'stop':
                 status.position = '0'
@@ -239,7 +240,7 @@ class Mpdclient(plugin.Plugin):
         except KeyError:
             logger.error('could not get all information from MPD status')
             return status
-        except ConnectionError:
+        except mpd.base.ConnectionError:
             self.on_connection_error()
             return status
 
@@ -279,7 +280,7 @@ class Mpdclient(plugin.Plugin):
             if key[-4:] == '.m3u':
                 key_list = [
                     'file: ' + file
-                    for file in self._mpdclient.listplaylist(key[:-4])
+                    for file in self._mpdclient.listplaylist(key)
                 ]
             else:
                 key_list = [
@@ -287,10 +288,10 @@ class Mpdclient(plugin.Plugin):
                     for file in self._mpdclient.search('base', key)
                 ]
 
-        except mpd.CommandError:
-            logger.error('could not apply status')
+        except mpd.CommandError as error:
+            logger.error(f'could not compare playlists ("{error}")')
             return False
-        except ConnectionError:
+        except mpd.base.ConnectionError:
             self.on_connection_error()
             return False
 
@@ -393,10 +394,10 @@ class Mpdclient(plugin.Plugin):
 
         try:
             self._mpdclient.play('0')
-        except mpd.CommandError:
-            logger.error('could not play')
+        except mpd.CommandError as error:
+            logger.error(f'could not play ("{error}")')
             return
-        except ConnectionError:
+        except mpd.base.ConnectionError:
             self.on_connection_error()
             return
 
@@ -425,10 +426,10 @@ class Mpdclient(plugin.Plugin):
                 self._mpdclient.play('0')
             else:
                 self._mpdclient.pause('0')
-        except mpd.CommandError:
-            logger.error('could not toggle')
+        except mpd.CommandError as error:
+            logger.error(f'could not toggle ("{error}")')
             return
-        except ConnectionError:
+        except mpd.base.ConnectionError:
             self.on_connection_error()
             return
 
@@ -449,10 +450,10 @@ class Mpdclient(plugin.Plugin):
         try:
             self._mpdclient.stop()
             self._mpdclient.seek('0', '0')
-        except mpd.CommandError:
-            logger.error('could not stop')
+        except mpd.CommandError as error:
+            logger.error('could not stop ("{error}")')
             return
-        except ConnectionError:
+        except mpd.base.ConnectionError:
             self.on_connection_error()
             return
 
@@ -472,10 +473,10 @@ class Mpdclient(plugin.Plugin):
 
         try:
             self._mpdclient.next()
-        except mpd.CommandError:
-            logger.error('could not jump to next title')
+        except mpd.CommandError as error:
+            logger.error(f'could not jump to next title ("{error}")')
             return
-        except ConnectionError:
+        except mpd.base.ConnectionError:
             self.on_connection_error()
             return
 
@@ -495,10 +496,10 @@ class Mpdclient(plugin.Plugin):
 
         try:
             self._mpdclient.previous()
-        except mpd.CommandError:
-            logger.error('could not jump to previous title')
+        except mpd.CommandError as error:
+            logger.error('could not jump to previous title ("{error}")')
             return
-        except ConnectionError:
+        except mpd.base.ConnectionError:
             self.on_connection_error()
             return
 
